You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@commons.apache.org by di...@apache.org on 2006/04/30 14:51:46 UTC

svn commit: r398329 - /jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/util/ArrayIterator.java

Author: dion
Date: Sun Apr 30 05:51:43 2006
New Revision: 398329

URL: http://svn.apache.org/viewcvs?rev=398329&view=rev
Log:
Checkstyle

Modified:
    jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/util/ArrayIterator.java

Modified: jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/util/ArrayIterator.java
URL: http://svn.apache.org/viewcvs/jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/util/ArrayIterator.java?rev=398329&r1=398328&r2=398329&view=diff
==============================================================================
--- jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/util/ArrayIterator.java (original)
+++ jakarta/commons/proper/jexl/trunk/src/java/org/apache/commons/jexl/util/ArrayIterator.java Sun Apr 30 05:51:43 2006
@@ -61,23 +61,23 @@
     /**
      * Creates a new iterator instance for the specified array.
      *
      * @param array The array for which an iterator is desired.
      */
-    public ArrayIterator(Object array) {
+    public ArrayIterator(Object arr) {
         /*
          * if this isn't an array, then throw.  Note that this is 
          * for internal use - so this should never happen - if it does
          *  we screwed up.
          */
          
-        if (!array.getClass().isArray()) {
+        if (!arr.getClass().isArray()) {
             throw new IllegalArgumentException("Programmer error :"
                       + " internal ArrayIterator invoked w/o array");
         }
             
-        this.array = array;
+        array = arr;
         pos = 0;
-        size = Array.getLength(this.array);
+        size = Array.getLength(array);
     }
 
     /**



---------------------------------------------------------------------
@@ -61,23 +61,23 @@
      * Creates a new iterator instance for the specified array.
      *
-     * @param array The array for which an iterator is desired.
+     * @param arr The array for which an iterator is desired.
      */
To unsubscribe, e-mail: commons-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: commons-dev-help@jakarta.apache.org